@@ -44,7 +44,7 @@ package Net::Songkick;
 use strict;
 use warnings;
 
-our $VERSION = '1.0.4';
+our $VERSION = '1.0.5';
 
 use Moose;
 
@@ -490,7 +490,7 @@ __PACKAGE__->meta->make_immutable;
 
 =head1 AUTHOR
 
-Dave Cross <dave@mag-sol.com>
+Dave Cross <dave@perlhacks.com>
 
 =head1 SEE ALSO
 
